gtk+ r20967 - in trunk: . gtk



Author: mitch
Date: Mon Aug  4 14:13:56 2008
New Revision: 20967
URL: http://svn.gnome.org/viewvc/gtk+?rev=20967&view=rev

Log:
2008-08-04  Michael Natterer  <mitch imendio com>

	* gtk/gtkclist.[ch]
	* gtk/gtkctree.[ch]
	* gtk/gtkitemfactory.[ch]
	* gtk/gtkobject.[ch]
	* gtk/gtksignal.[ch]: s/GtkDestroyNotify/GDestroyNotify/g



Modified:
   trunk/ChangeLog
   trunk/gtk/gtkclist.c
   trunk/gtk/gtkclist.h
   trunk/gtk/gtkctree.c
   trunk/gtk/gtkctree.h
   trunk/gtk/gtkitemfactory.c
   trunk/gtk/gtkitemfactory.h
   trunk/gtk/gtkobject.c
   trunk/gtk/gtkobject.h
   trunk/gtk/gtksignal.c
   trunk/gtk/gtksignal.h

Modified: trunk/gtk/gtkclist.c
==============================================================================
--- trunk/gtk/gtkclist.c	(original)
+++ trunk/gtk/gtkclist.c	Mon Aug  4 14:13:56 2008
@@ -3071,10 +3071,10 @@
 }
 
 void
-gtk_clist_set_row_data_full (GtkCList         *clist,
-			     gint              row,
-			     gpointer          data,
-			     GtkDestroyNotify  destroy)
+gtk_clist_set_row_data_full (GtkCList       *clist,
+			     gint            row,
+			     gpointer        data,
+			     GDestroyNotify  destroy)
 {
   GtkCListRow *clist_row;
 

Modified: trunk/gtk/gtkclist.h
==============================================================================
--- trunk/gtk/gtkclist.h	(original)
+++ trunk/gtk/gtkclist.h	Mon Aug  4 14:13:56 2008
@@ -352,7 +352,7 @@
   GtkStyle *style;
 
   gpointer data;
-  GtkDestroyNotify destroy;
+  GDestroyNotify destroy;
   
   guint fg_set     : 1;
   guint bg_set     : 1;
@@ -699,10 +699,10 @@
 			     gpointer  data);
 
 /* sets a data pointer for a given row with destroy notification */
-void gtk_clist_set_row_data_full (GtkCList         *clist,
-			          gint              row,
-			          gpointer          data,
-				  GtkDestroyNotify  destroy);
+void gtk_clist_set_row_data_full (GtkCList       *clist,
+			          gint            row,
+			          gpointer        data,
+				  GDestroyNotify  destroy);
 
 /* returns the data set for a row */
 gpointer gtk_clist_get_row_data (GtkCList *clist,

Modified: trunk/gtk/gtkctree.c
==============================================================================
--- trunk/gtk/gtkctree.c	(original)
+++ trunk/gtk/gtkctree.c	Mon Aug  4 14:13:56 2008
@@ -3267,7 +3267,7 @@
 
   if (ctree_row->row.destroy)
     {
-      GtkDestroyNotify dnotify = ctree_row->row.destroy;
+      GDestroyNotify dnotify = ctree_row->row.destroy;
       gpointer ddata = ctree_row->row.data;
 
       ctree_row->row.destroy = NULL;
@@ -5131,12 +5131,12 @@
 }
 
 void
-gtk_ctree_node_set_row_data_full (GtkCTree         *ctree,
-				  GtkCTreeNode     *node,
-				  gpointer          data,
-				  GtkDestroyNotify  destroy)
+gtk_ctree_node_set_row_data_full (GtkCTree       *ctree,
+				  GtkCTreeNode   *node,
+				  gpointer        data,
+				  GDestroyNotify  destroy)
 {
-  GtkDestroyNotify dnotify;
+  GDestroyNotify dnotify;
   gpointer ddata;
   
   g_return_if_fail (GTK_IS_CTREE (ctree));

Modified: trunk/gtk/gtkctree.h
==============================================================================
--- trunk/gtk/gtkctree.h	(original)
+++ trunk/gtk/gtkctree.h	Mon Aug  4 14:13:56 2008
@@ -392,7 +392,7 @@
 void gtk_ctree_node_set_row_data_full            (GtkCTree     *ctree,
 						  GtkCTreeNode *node,
 						  gpointer      data,
-						  GtkDestroyNotify destroy);
+						  GDestroyNotify destroy);
 gpointer gtk_ctree_node_get_row_data             (GtkCTree     *ctree,
 						  GtkCTreeNode *node);
 void gtk_ctree_node_moveto                       (GtkCTree     *ctree,

Modified: trunk/gtk/gtkitemfactory.c
==============================================================================
--- trunk/gtk/gtkitemfactory.h	(original)
+++ trunk/gtk/gtkitemfactory.h	Mon Aug  4 14:13:56 2008
@@ -73,7 +73,7 @@
 
   GtkTranslateFunc       translate_func;
   gpointer               translate_data;
-  GtkDestroyNotify       translate_notify;   
+  GDestroyNotify         translate_notify;
 };
 
 struct _GtkItemFactoryClass
@@ -184,7 +184,7 @@
 					 guint32		 time_);
 void	gtk_item_factory_popup_with_data(GtkItemFactory		*ifactory,
 					 gpointer		 popup_data,
-					 GtkDestroyNotify	 destroy,
+					 GDestroyNotify          destroy,
 					 guint			 x,
 					 guint			 y,
 					 guint			 mouse_button,
@@ -194,7 +194,7 @@
 void   gtk_item_factory_set_translate_func (GtkItemFactory      *ifactory,
 					    GtkTranslateFunc     func,
 					    gpointer             data,
-					    GtkDestroyNotify     notify);
+					    GDestroyNotify       notify);
 
 /* Compatibility functions for deprecated GtkMenuFactory code
  */

Modified: trunk/gtk/gtkobject.c
==============================================================================
--- trunk/gtk/gtkobject.c	(original)
+++ trunk/gtk/gtkobject.c	Mon Aug  4 14:13:56 2008
@@ -520,15 +520,15 @@
 
 struct _GtkWeakRef
 {
-  GtkWeakRef	   *next;
-  GtkDestroyNotify  notify;
-  gpointer          data;
+  GtkWeakRef	 *next;
+  GDestroyNotify  notify;
+  gpointer        data;
 };
 
 void
-gtk_object_weakref (GtkObject        *object,
-		    GtkDestroyNotify  notify,
-		    gpointer          data)
+gtk_object_weakref (GtkObject      *object,
+		    GDestroyNotify  notify,
+		    gpointer        data)
 {
   GtkWeakRef *weak;
 
@@ -546,9 +546,9 @@
 }
 
 void
-gtk_object_weakunref (GtkObject        *object,
-		      GtkDestroyNotify  notify,
-		      gpointer          data)
+gtk_object_weakunref (GtkObject      *object,
+		      GDestroyNotify  notify,
+		      gpointer        data)
 {
   GtkWeakRef *weaks, *w, **wp;
 
@@ -664,10 +664,10 @@
 }
 
 void
-gtk_object_set_data_by_id_full (GtkObject        *object,
-				GQuark		  data_id,
-				gpointer          data,
-				GtkDestroyNotify  destroy)
+gtk_object_set_data_by_id_full (GtkObject      *object,
+				GQuark		data_id,
+				gpointer        data,
+				GDestroyNotify  destroy)
 {
   g_return_if_fail (GTK_IS_OBJECT (object));
 
@@ -675,10 +675,10 @@
 }
 
 void
-gtk_object_set_data_full (GtkObject        *object,
-			  const gchar      *key,
-			  gpointer          data,
-			  GtkDestroyNotify  destroy)
+gtk_object_set_data_full (GtkObject      *object,
+			  const gchar    *key,
+			  gpointer        data,
+			  GDestroyNotify  destroy)
 {
   g_return_if_fail (GTK_IS_OBJECT (object));
   g_return_if_fail (key != NULL);

Modified: trunk/gtk/gtkobject.h
==============================================================================
--- trunk/gtk/gtkobject.h	(original)
+++ trunk/gtk/gtkobject.h	Mon Aug  4 14:13:56 2008
@@ -141,10 +141,10 @@
 GtkObject*	gtk_object_ref		  (GtkObject	      *object);
 void		gtk_object_unref	  (GtkObject	      *object);
 void gtk_object_weakref	  (GtkObject	    *object,
-			   GtkDestroyNotify  notify,
+			   GDestroyNotify    notify,
 			   gpointer	     data);
 void gtk_object_weakunref (GtkObject	    *object,
-			   GtkDestroyNotify  notify,
+			   GDestroyNotify    notify,
 			   gpointer	     data);
 
 /* Set 'data' to the "object_data" field of the object. The
@@ -165,7 +165,7 @@
 void	 gtk_object_set_data_full    (GtkObject	     *object,
 				      const gchar    *key,
 				      gpointer	      data,
-				      GtkDestroyNotify destroy);
+				      GDestroyNotify  destroy);
 void	 gtk_object_remove_data	     (GtkObject	     *object,
 				      const gchar    *key);
 gpointer gtk_object_get_data	     (GtkObject	     *object,
@@ -192,7 +192,7 @@
 void gtk_object_set_data_by_id_full	(GtkObject	 *object,
 					 GQuark		  data_id,
 					 gpointer	  data,
-					 GtkDestroyNotify destroy);
+					 GDestroyNotify   destroy);
 gpointer gtk_object_get_data_by_id	(GtkObject	 *object,
 					 GQuark		  data_id);
 void  gtk_object_remove_data_by_id	(GtkObject	 *object,

Modified: trunk/gtk/gtksignal.c
==============================================================================
--- trunk/gtk/gtksignal.c	(original)
+++ trunk/gtk/gtksignal.c	Mon Aug  4 14:13:56 2008
@@ -138,7 +138,7 @@
 			 GtkSignalFunc        func,
 			 GtkCallbackMarshal   unsupported,
 			 gpointer             data,
-			 GtkDestroyNotify     destroy_func,
+			 GDestroyNotify       destroy_func,
 			 gint                 object_signal,
 			 gint                 after)
 {

Modified: trunk/gtk/gtksignal.h
==============================================================================
--- trunk/gtk/gtksignal.h	(original)
+++ trunk/gtk/gtksignal.h	Mon Aug  4 14:13:56 2008
@@ -121,7 +121,7 @@
 						 GtkSignalFunc	     func,
 						 GtkCallbackMarshal  unsupported,
 						 gpointer	     data,
-						 GtkDestroyNotify    destroy_func,
+						 GDestroyNotify      destroy_func,
 						 gint		     object_signal,
 						 gint		     after);
 void	gtk_signal_emitv			(GtkObject	    *object,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/gtk/gtkitemfactory.c	(original)
+++ trunk/gtk/gtkitemfactory.c	Mon Aug  4 14:13:56 2008
@@ -1482,7 +1482,7 @@
  * gtk_item_factory_popup_with_data:
  * @ifactory: a #GtkItemFactory of type #GTK_TYPE_MENU (see gtk_item_factory_new())
  * @popup_data: data available for callbacks while the menu is posted
  * @destroy: a #GtkDestroyNotify function to be called on @popup_data when
  *  the menu is unposted
  * @x: the x position 
  * @y: the y position
@@ -1510,7 +1510,7 @@
 void
 gtk_item_factory_popup_with_data (GtkItemFactory	*ifactory,
 				  gpointer		 popup_data,
-				  GtkDestroyNotify	 destroy,
+				  GDestroyNotify         destroy,
 				  guint			 x,
 				  guint			 y,
 				  guint			 mouse_button,
@@ -1558,7 +1558,7 @@
  * @ifactory: a #GtkItemFactory
  * @func: the #GtkTranslateFunc function to be used to translate path elements 
  * @data: data to pass to @func and @notify
  * @notify: a #GtkDestroyNotify function to be called when @ifactory is 
  *   destroyed and when the translation function is changed again
  * 
  * Sets a function to be used for translating the path elements before they
@@ -1567,10 +1567,10 @@
  * Deprecated: 2.4: Use #GtkUIManager instead.
  */ 
 void
-gtk_item_factory_set_translate_func (GtkItemFactory      *ifactory,
-				     GtkTranslateFunc     func,
-				     gpointer             data,
-				     GtkDestroyNotify     notify)
+gtk_item_factory_set_translate_func (GtkItemFactory    *ifactory,
+				     GtkTranslateFunc   func,
+				     gpointer           data,
+				     GDestroyNotify     notify)
 {
   g_return_if_fail (ifactory != NULL);
   
@@ -1482,7 +1482,7 @@
  * @ifactory: a #GtkItemFactory of type #GTK_TYPE_MENU (see gtk_item_factory_new())
  * @popup_data: data available for callbacks while the menu is posted
- * @destroy: a #GtkDestroyNotify function to be called on @popup_data when
+ * @destroy: a #GDestroyNotify function to be called on @popup_data when
  *  the menu is unposted
  * @x: the x position 
@@ -1558,7 +1558,7 @@
  * @func: the #GtkTranslateFunc function to be used to translate path elements 
  * @data: data to pass to @func and @notify
- * @notify: a #GtkDestroyNotify function to be called when @ifactory is 
+ * @notify: a #GDestroyNotify function to be called when @ifactory is 
  *   destroyed and when the translation function is changed again
  * 

Modified: trunk/gtk/gtkitemfactory.h
==============================================================================